@@ -1,13 +1,12 @@
 """Mandatory (MUST) requirement checking functions
 """
-import collections
+from collections.abc import Mapping
 import operator
 import re
 import uuid
 
 from cpe import CPE
 from dateutil import parser
-from six import string_types
 from stix2patterns.v21.pattern import Pattern
 from stix2patterns.validator import run_validator as pattern_validator
 
@@ -60,7 +59,7 @@ def timestamp(instance):
                                                 % (obj['type'], tprop, obj[tprop], str(e)), instance['id'])
                 if obj['type'] in enums.TIMESTAMP_EMBEDDED_PROPERTIES:
                     for embed in enums.TIMESTAMP_EMBEDDED_PROPERTIES[obj['type']]:
-                        if embed in obj and isinstance(obj[embed], collections.Mapping):
+                        if embed in obj and isinstance(obj[embed], Mapping):
                             for tprop in enums.TIMESTAMP_EMBEDDED_PROPERTIES[obj['type']][embed]:
                                 if embed == 'extensions':
                                     for ext in obj[embed]:
@@ -90,7 +89,7 @@ def timestamp(instance):
                                             % (instance['type'], tprop, instance[tprop], str(e)), instance['id'])
             if instance['type'] in enums.TIMESTAMP_EMBEDDED_PROPERTIES:
                 for embed in enums.TIMESTAMP_EMBEDDED_PROPERTIES[instance['type']]:
-                    if embed in instance and isinstance(instance[embed], collections.Mapping):
+                    if embed in instance and isinstance(instance[embed], Mapping):
                         for tprop in enums.TIMESTAMP_EMBEDDED_PROPERTIES[instance['type']][embed]:
                             if embed == 'extensions':
                                 for ext in instance[embed]:
@@ -411,7 +410,7 @@ def patterns(instance, options):
     objects and properties referenced by the pattern are valid.
     """
     if (instance['type'] != 'indicator' or instance.get('pattern_type', '') != 'stix' or
-            isinstance(instance.get('pattern', ''), string_types) is False):
+            isinstance(instance.get('pattern', ''), str) is False):
         return
 
     pattern = instance['pattern']
